==> percona-xtrabackup_8.0.35-30.orig.tar.gz: percona-xtrabackup-8.0.35-30/storage/ndb/src/ndbapi/ndb_internal.cpp <==
/*
   Copyright (c) 2010, 2023, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#include "API.hpp"
#include "ndb_internal.hpp"

int
Ndb_internal::send_event_report(bool is_poll_owner,
                                Ndb *ndb,
                                Uint32 *data,
                                Uint32 length)
{
  return ndb->theImpl->send_event_report(is_poll_owner, data, length);
}

void
Ndb_internal::setForceShortRequests(Ndb* ndb, bool val)
{
  ndb->theImpl->forceShortRequests = val;
}

void
Ndb_internal::set_TC_COMMIT_ACK_immediate(Ndb *ndb, bool flag)
{
  ndb->theImpl->set_TC_COMMIT_ACK_immediate(flag);
}

int
Ndb_internal::send_dump_state_all(Ndb *ndb,
                                  Uint32 *dumpStateCodeArray,
                                  Uint32 len)
{
  return ndb->theImpl->send_dump_state_all(dumpStateCodeArray, len);
}

==> percona-xtrabackup-8.3.0-1.tar.gz: percona-xtrabackup-8.3.0-1/storage/ndb/src/ndbapi/ndb_internal.cpp <==
/*
   Copyright (c) 2010, 2023, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#include "ndb_internal.hpp"
#include "API.hpp"

int Ndb_internal::send_event_report(bool is_poll_owner, Ndb *ndb, Uint32 *data,
                                    Uint32 length) {
  return ndb->theImpl->send_event_report(is_poll_owner, data, length);
}

void Ndb_internal::setForceShortRequests(Ndb *ndb, bool val) {
  ndb->theImpl->forceShortRequests = val;
}

void Ndb_internal::set_TC_COMMIT_ACK_immediate(Ndb *ndb, bool flag) {
  ndb->theImpl->set_TC_COMMIT_ACK_immediate(flag);
}

int Ndb_internal::send_dump_state_all(Ndb *ndb, Uint32 *dumpStateCodeArray,
                                      Uint32 len) {
  return ndb->theImpl->send_dump_state_all(dumpStateCodeArray, len);
}
